@@ -196,7 +196,7 @@ public class Tables {
 
         /* Check the shape arrays look OK. */
         int[] nels = new int[ ncol ];
-        Class[] classes = new Class[ ncol ];
+        Class<?>[] classes = new Class<?>[ ncol ];
         ColumnInfo[] colinfos = new ColumnInfo[ ncol ];
         for ( int icol = 0; icol < ncol; icol++ ) {
             ColumnInfo cinfo = table.getColumnInfo( icol );
@@ -332,10 +332,10 @@ public class Tables {
      * @return  table sequence containing input tables
      */
     public static TableSequence arrayTableSequence( StarTable[] tables ) {
-        final Iterator it = Arrays.asList( tables ).iterator();
+        final Iterator<StarTable> it = Arrays.asList( tables ).iterator();
         return new TableSequence() {
             public StarTable nextTable() {
-                return it.hasNext() ? (StarTable) it.next()
+                return it.hasNext() ? it.next()
                                     : null;
             }
         };
@@ -470,6 +470,7 @@ public class Tables {
      * @return   utype string, or null if none is available
      * @see   #setUtype
      */
+    @Deprecated
     public static String getUtype( ValueInfo info ) {
         return info.getUtype();
     }
@@ -482,6 +483,7 @@ public class Tables {
      * @param  utype  new utype value
      * @see   #getUtype
      */
+    @Deprecated
     public static void setUtype( ValueInfo info, String utype ) {
         if ( info instanceof DefaultValueInfo ) {
             ((DefaultValueInfo) info).setUtype( utype );
@@ -498,19 +500,16 @@ public class Tables {
      * @param   info   key giving the value you want
      * @return  matching value  
      */
-    public static Object getValue( Collection dvals, ValueInfo info ) {
+    public static Object getValue( Collection<DescribedValue> dvals,
+                                   ValueInfo info ) {
         String iname = info.getName();
-        Class iclazz = info.getContentClass();
+        Class<?> iclazz = info.getContentClass();
         if ( iname != null && iclazz != null ) {
-            for ( Iterator it = dvals.iterator(); it.hasNext(); ) {
-                Object obj = it.next();
-                if ( obj instanceof DescribedValue ) {
-                    DescribedValue dval = (DescribedValue) obj;
-                    ValueInfo dinfo = dval.getInfo();
-                    if ( iname.equals( dinfo.getName() ) &&
-                         iclazz.equals( dinfo.getContentClass() ) ) {
-                        return dval.getValue();
-                    }
+            for ( DescribedValue dval : dvals ) {
+                ValueInfo dinfo = dval.getInfo();
+                if ( iname.equals( dinfo.getName() ) &&
+                     iclazz.equals( dinfo.getContentClass() ) ) {
+                    return dval.getValue();
                 }
             }
         }
