@@ -4,7 +4,6 @@ import java.io.IOException;
 import java.io.OutputStream;
 import java.net.URL;
 import java.util.Arrays;
-import java.util.Iterator;
 import uk.ac.starlink.table.AbstractStarTable;
 import uk.ac.starlink.table.ColumnData;
 import uk.ac.starlink.table.ColumnInfo;
@@ -109,8 +108,7 @@ public class TstTableWriter extends StreamStarTableWriter {
         /* Write parameters. */
         if ( ! st.getParameters().isEmpty() ) {
             printLine( out, "# Table parameters" );
-            for ( Iterator it = st.getParameters().iterator(); it.hasNext(); ) {
-                DescribedValue dval = (DescribedValue) it.next();
+            for ( DescribedValue dval : st.getParameters() ) {
                 String name = dval.getInfo().getName();
                 Object value = dval.getValue();
                 if ( name != null && name.trim().length() > 0 &&
@@ -196,7 +194,7 @@ public class TstTableWriter extends StreamStarTableWriter {
         RowSequence rseq = st.getRowSequence();
         try {
             while ( rseq.next() ) {
-                Object[] row = (Object[]) rseq.getRow();
+                Object[] row = rseq.getRow();
                 String[] srow = new String[ ncol ];
                 for ( int icol = 0; icol < ncol; icol++ ) {
                     String sval = colInfos[ icol ]
@@ -293,7 +291,7 @@ public class TstTableWriter extends StreamStarTableWriter {
             String name = info.getName();
             String ucd = info.getUCD();
             String units = info.getUnitString();
-            Class clazz = info.getContentClass();
+            Class<?> clazz = info.getContentClass();
             String lucd = ucd == null ? "" : ucd.toLowerCase();
             String lname = name == null ? "" : name.toLowerCase();
             String lunits = units == null ? "" : units.toLowerCase();
